@@ -1,7 +1,7 @@
 package Forest::Tree::Writer;
 use Moose::Role;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'tree' => (
@@ -17,7 +17,7 @@ sub write {
     print $fh $self->as_string;
 }
 
-1;
+no Moose::Role; 1;
 
 __END__
 
